/*
*  GetHostBy utility
*  
*  source/gethostby.c
*  snapshot 20040217
*  
*  (c) 6.1.2003 Jaroslav Beran berk@volny.cz http://www.volny.cz/berk
*  License GNU/GPL2  
*/


#include <stdio.h>
#include "netlib.h"


#define VERSION "GetHostBy snapshot 20040216 cz"


void print_help(char *program);
void host_info(struct hostent *H);
int by_name(char *name, int vebrose);
int by_addr(char *addr, int vebrose);


int main(int argc, char *argv[])
{
        int vebrose;
        int ret = 0;

        if((argc < 3) || (argc > 4)){
                print_help(argv[0]);
                return -1;
        }

        if(strcmp(argv[1], "name") && strcmp(argv[1], "addr")){
                print_help(argv[0]);
                return -1;
        }

        if((argc == 4) && (strcmp(argv[3], "-v"))){
                print_help(argv[0]);
                return -1;
        }

        vebrose = (argc == 4) ? 1 : 0;

        if(! strcmp(argv[1], "name"))
                ret = by_name(argv[2], vebrose);

        if(! strcmp(argv[1], "addr"))
                ret = by_addr(argv[2], vebrose);

        return ret;
}


void print_help(char *program)
{
        printf("%s - program pro preklad jmen na ip adresy a naopak\n", VERSION);
        printf("(c)2003 Jaroslav Beran - berk@volny.cz http://www.volny.cz/berk\n");
        printf("Licence GNU/GPL2 (http://www.gnu.cz)\n\n");
        printf("\n");
        printf("Pouziti:\n");
        printf("%s name domenove_jmeno [volby]\n", program);
        printf("%s addr ip_adresa [volby]\n", program);
        printf("\n");
        printf("Volby:\n");
        printf("-v     Upovidany rezim\n");

        return;
}


void host_info(struct hostent *H)
{
        char **alternativy;
        register int index;

        printf("Oficialni jmeno: %s\n", H->h_name);

        printf("Alternativy:\n");
        alternativy = H->h_aliases;
        while(*alternativy != NULL)
                printf("\t%s\n", *(alternativy++));

        printf("Adresy\n");
        index = 0;
        while(H->h_addr_list[index] != NULL)
                printf("\t%s\n", inet_ntoa(*(struct in_addr *)H->h_addr_list[index++]));

        printf("Pocet adres: %d\n", index);
        printf("Velikost adres: %d\n", H->h_length);

        return;
}


int by_name(char *name, int vebrose)
{
        struct hostent *H;


        if (init_netlib() != 0){
                puts("Nepodarilo se inicializovat sockety\n");
                return -1;
        }

        printf("Informace o %s:\n", name);
        H = gethostbyname(name);

        if (H == NULL){
                puts("Nepodarilo se zjistit adresu");
                close_netlib();
                return -1;
        }

        host_info(H);
        close_netlib();

        return 0;
}


int by_addr(char *addr, int vebrose)
{
        struct hostent *H;
        struct in_addr adresa;


        if (init_netlib() != 0){
                puts("Nepodarilo se inicializovat sockety\n");
                return -1;
        }

        #ifdef __linux__
        if ((adresa.s_addr = inet_addr(addr)) == INADDR_NONE){
        #else
        if ((adresa.S_un.S_addr = inet_addr(addr)) == INADDR_NONE){
        #endif
                printf("%s neni spravny zapis ip adresy\n", addr);
                close_netlib();
                return -1;
        }

        printf("Informace o %s:\n", addr);
        H = gethostbyaddr((char *) &adresa, 4, AF_INET);
        if (H == NULL){
                puts("Nepodarilo se zjistit jmeno");
                close_netlib();
                return -1;
        }

        host_info(H);
        close_netlib();

        return 0;
}
